package com.ruoyi.bst.areaSub.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.bst.areaSub.domain.AreaSub;
import com.ruoyi.bst.areaSub.domain.AreaSubQuery;
import com.ruoyi.bst.areaSub.domain.AreaSubVO;
import com.ruoyi.bst.areaSub.domain.vo.AreaSubCountTypeByAreaVO;

/**
 * 子区域Mapper接口
 *
 * @author ruoyi
 * @date 2025-03-15
 */
public interface AreaSubMapper
{
    /**
     * 查询子区域
     *
     * @param id 子区域主键
     * @return 子区域
     */
    AreaSubVO selectAreaSubById(Long id);

    /**
     * 查询子区域列表
     *
     * @param query 子区域
     * @return 子区域集合
     */
    List<AreaSubVO> selectAreaSubList(@Param("query")AreaSubQuery query);

    /**
     * 新增子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    int insertAreaSub(AreaSub areaSub);

    /**
     * 修改子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    public int updateAreaSub(@Param("data") AreaSub areaSub);

    /**
     * 删除子区域
     *
     * @param id 子区域主键
     * @return 结果
     */
    int deleteAreaSubById(Long id);

    /**
     * 批量删除子区域
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAreaSubByIds(Long[] ids);

    List<AreaSubCountTypeByAreaVO> selectTypeCountGroupByAreaId(@Param("query") AreaSubQuery query);

    /**
     * 根据查询条件查询子区域ID列表
     * @param query 查询条件
     * @return 子区域ID列表
     */
    List<Long> selectIdByQuery(@Param("query") AreaSubQuery query);

    /**
     * 逻辑删除子区域
     * @param ids 子区域ID列表
     * @return 结果
     */
    int logicDel(@Param("ids") List<Long> ids);
}
